@@ -1,3 +1,6 @@
+"""
+Moic cli definition base module
+"""
 import click
 
 from moic.cli.config import config
@@ -24,8 +27,14 @@ cli.add_command(rabbit)
 
 
 def run():
+    """
+    Run the cli application
+    """
     cli()
 
 
 if __name__ == "__main__":
+    """
+    Main method of the module
+    """
     cli()
