@@ -1,4 +1,7 @@
 # flake8: noqa
+"""
+Module for Moic fun commands
+"""
 import click
 
 from moic.config import console
@@ -6,26 +9,28 @@ from moic.config import console
 
 @click.command()
 def rabbit():
-    """Print an amazing rabbit"""
+    """
+    Print an amazing rabbit: Tribute to @fattibenji https://github.com/fattybenji
+    """
     funny_rabbit = """
               /|      __
              / |   ,-~ /
             Y :|  //  /
             | jj /( .^
-             >-\"~\"-v\"
+             >-"~"-v"
             /       Y
            jo  o    |
           ( ~T~     j    Hello !
            >._-' _./
-          /   \"~\"  |
+          /   "~"  |
          Y     _,  |
-        /| ;-\"~ _  l
-       / l/ ,-\"~    \\
-       \\//\\/      .- \\
+        /| ;-"~ _  l
+       / l/ ,-"~    \\
+       \//\/      .- \\
         Y        /    Y
         l       I     !
-        ]\      _\    /\"\\
-       (\" ~----( ~   Y.  )
+        ]\      _\    /"\\
+       (" ~----( ~   Y.  )
     """
 
     console.print(funny_rabbit)
