@@ -1,3 +1,6 @@
+"""
+Module for base Moic issue commands
+"""
 import os
 import time
 from datetime import datetime
@@ -11,24 +14,12 @@ from moic.cli.completion import (
     autocomplete_transitions,
     autocomplete_users,
 )
-from moic.cli.utils import (
-    get_issue_commits,
-    get_template,
-    print_issue,
-    print_issues,
-    validate_issue_key,
-    validate_priority,
-)
+from moic.cli.utils import get_issue_commits, get_template, print_issue, print_issues
 from moic.cli.utils.converter import Jira2Markdown
-from moic.config import COLOR_MAP, CONF_DIR, PRIORITY_COLORS, JiraInstance, console, logger, settings
-
-# Custom fileds
-# Sprint : 10101
-# Epic   : 10102
-# Peer : customfield_10800
+from moic.cli.validators import validate_issue_key, validate_priority
+from moic.config import COLOR_MAP, CONF_DIR, PRIORITY_COLORS, JiraInstance, console, settings
 
 
-# TODO: Add change priority command
 # TODO: Add change issue type command
 # TODO: Manage labels
 # TODO: Manage components
@@ -44,7 +35,7 @@ def issue():
 )
 @click.option("--all", default=False, help="Search over all Jira Projects")
 @click.option(
-    "--project", default=settings.get("default_project", None), help="Project ID to scope search",
+    "--project", default=settings.get("project", None), help="Project ID to scope search",
 )
 @click.option("--search", default=None, help="JQL query for searching issues")
 @click.option("--oneline", default=False, help="Dislay issue on one line", is_flag=True)
@@ -52,17 +43,14 @@ def issue():
 @click.option("--commits", default=False, help="Dislay issue commits", is_flag=True)
 def get(id, all, project, search, oneline, subtasks, commits):
     """Get a Jira issue"""
-    logger.debug("get issue")
     if not id and not search:
         return console.print("You must specify an issue ID or a search query")
     try:
         jira = JiraInstance()
-        logger.debug("build search query")
         if search:
             if project and not all and "project" not in search:
                 search = f"{search} AND project = {project}"
 
-            logger.debug(f"search: {search}")
             issues = jira.session.search_issues(search)
         else:
             issues = [jira.session.issue(id)]
@@ -74,6 +62,7 @@ def get(id, all, project, search, oneline, subtasks, commits):
 @issue.command()
 @click.argument("issue-key", type=click.STRING, autocompletion=autocomplete_issues, callback=validate_issue_key)
 def show(issue_key):
+    """Show a Jira Issue description"""
     try:
         jira = JiraInstance()
         issue = jira.session.issue(issue_key)
@@ -89,7 +78,7 @@ def show(issue_key):
 @issue.command()
 @click.argument("summary")
 @click.option(
-    "--project", default=settings.get("default_project", None), help="Jira project where create the issue",
+    "--project", default=settings.get("project", None), help="Jira project where create the issue",
 )
 @click.option("--issue-type", default="Story", help="Jira issue type")
 @click.option("--priority", default="", help="Jira issue priority")
@@ -209,7 +198,7 @@ def set_peer(issue_key, peer):
 )
 @click.option("--subtask", "-s", type=click.STRING, help="The subtask title", multiple=True)
 def add_subtasks(issue_key, subtask):
-    """Assign a Jira issue"""
+    """Add subtasks to a Jira issue"""
     try:
         jira = JiraInstance()
 
@@ -270,6 +259,7 @@ def move(issue_key, transition):
 )
 @click.argument("priority", type=click.STRING, autocompletion=autocomplete_priorities, callback=validate_priority)
 def rank(issue_key, priority):
+    """Change the priority of a Jira issue"""
     try:
         jira = JiraInstance()
         issue = jira.session.issue(issue_key)
