@@ -1,3 +1,6 @@
+"""
+Module for base Moic sprint commands
+"""
 import concurrent.futures
 import os
 import time
@@ -7,8 +10,15 @@ import click
 from rich.progress import track
 
 from moic.cli.completion import autcomplete_projects
-from moic.cli.utils import print_issues, print_status
-from moic.config import COLOR_MAP, SPRINT_STATUS_COLORS, JiraInstance, console, logger, settings
+from moic.cli.utils import (
+    get_board_sprints,
+    get_project_boards,
+    get_sprint_issues,
+    get_sprint_story_points,
+    print_issues,
+    print_status,
+)
+from moic.config import COLOR_MAP, SPRINT_STATUS_COLORS, JiraInstance, console, settings
 
 STEPS = ["new", "indeterminate", "done"]
 
@@ -18,7 +28,7 @@ STEPS = ["new", "indeterminate", "done"]
 def sprint():
     """Create, edit, list Jira Sprints"""
     if not settings.get("jira.custom_fields.story_points"):
-        JiraInstance().configure_agile(settings.get("default_project"))
+        JiraInstance().configure_agile(settings.get("project"))
         return
 
 
@@ -27,7 +37,7 @@ def sprint():
 @click.option("--board", default=None, help="Specify Jira Board name")
 @click.option(
     "--project",
-    default=settings.get("default_project", None),
+    default=settings.get("project", None),
     help="Specify a project key",
     autocompletion=autcomplete_projects,
 )
@@ -38,7 +48,10 @@ def list(board, project, closed):
         jira = JiraInstance()
         if not board:
             if project and project != "all":
-                jira_boards = jira.session.boards(type="scrum", projectKeyOrID=project)
+                # This function is used waiting the 3.0.0 release of Python Jira
+                # which include it built-in
+                # jira_boards = jira.session.boards(type="scrum", projectKeyOrID=project)
+                jira_boards = get_project_boards(project)
             else:
                 jira_boards = jira.session.boards(type="scrum")
         else:
@@ -96,88 +109,28 @@ def list(board, project, closed):
         console.print(f"[red]Something goes wrong {e}[/red]")
 
 
-def get_board_sprints(board_id, closed=False):
-    """Return le sprint list of a board"""
-    logger.debug(f"Get board sprints: {board_id} - start")
-    sprints = JiraInstance().session.sprints(board_id)
-    if not closed:
-        sprints = [jira_sprint for jira_sprint in sprints if jira_sprint.state != "closed"]
-    ret = {"board_id": board_id, "sprints": sprints}
-    logger.debug(f"Get board sprints: {board_id} - done")
-    return ret
-
-
-def get_sprint_story_points(sprint_id):
-    """Return the detailled list of story points for a given sprint Id"""
-    start_time = time.time()
-    logger.debug(f"Get sprint issue: {sprint_id} - start")
-
-    jira = JiraInstance()
-    issues = [
-        issue
-        for issue in jira.session.search_issues(f"Sprint = {sprint_id}")
-        if settings.get("jira.custom_fields.story_points") in issue.raw["fields"].keys()
-    ]
-
-    done = [issue for issue in issues if issue.fields.status.statusCategory.key == "done"]
-    todo = [issue for issue in issues if issue not in done]
-
-    ret = {
-        "sprint_id": sprint_id,
-        "points": {
-            "done": float(
-                sum(
-                    [
-                        float(
-                            0
-                            if issue.raw["fields"][settings.get("jira.custom_fields.story_points")] is None
-                            else issue.raw["fields"][settings.get("jira.custom_fields.story_points")]
-                        )
-                        for issue in done
-                    ]
-                )
-            ),
-            "todo": float(
-                sum(
-                    [
-                        float(
-                            0
-                            if issue.raw["fields"][settings.get("jira.custom_fields.story_points")] is None
-                            else issue.raw["fields"][settings.get("jira.custom_fields.story_points")]
-                        )
-                        for issue in todo
-                    ]
-                )
-            ),
-        },
-    }
-    logger.debug(f"Get sprint issue: {sprint_id} - done {(time.time() - start_time)}")
-    return ret
-
-
-def get_sprint_issues(sprint_id):
-    jira = JiraInstance()
-    return jira.session.search_issues(f"sprint = {sprint_id}")
-
-
 @sprint.command()
 # TODO: Add autocomplete
 @click.option("--board", default=None, help="Specify Jira Board name")
 @click.option("--sprint", default=None, help="Specify Jira Sprint id")
 @click.option(
     "--project",
-    default=settings.get("default_project", None),
+    default=settings.get("project", None),
     help="Specify a project key",
     autocompletion=autcomplete_projects,
 )
 @click.option("--subtasks", default=False, help="Display story subtask", is_flag=True)
 def get(board, sprint, project, subtasks):
+    """Get Jira sprints link to a board"""
     if not settings.get(f"jira.projects.{project}.workflow"):
         JiraInstance().configure_agile(project)
 
     jira = JiraInstance()
     if not board and not sprint:
-        board = jira.session.boards(type="scrum", projectKeyOrID=project)[0]
+        # This function is used waiting the 3.0.0 release of Python Jira
+        # which include it built-in
+        # jira_boards = jira.session.boards(type="scrum", projectKeyOrID=project)[0]
+        board = get_project_boards(project)[0]
         sprints = jira.session.sprints(board.id, state="active")
     elif sprint:
         sprints = [jira.session.sprint(sprint)]
