@@ -1,3 +1,6 @@
+"""
+Module for Moic configuration
+"""
 import json
 import logging
 import os
@@ -44,29 +47,64 @@ logger.addHandler(stream_handler)
 
 
 class JiraInstance:
+    """
+    JiraInstance class which allow you to access Jira's API using basic auth credentials
+    It allows to setup several configuration such as:
+    - Default project, custom fields, sprint workflow etc...
+    """
 
     instance = None
 
-    def __init__(self):
+    def __init__(self) -> None:
+        """
+        Init method
+        """
         self.setup_home_dir()
 
     @property
-    def session(self):
+    def session(self) -> JIRA:
+        """
+        Session object which represents a JIRA API session
+
+        Returns:
+            JIRA: A Jira API session
+        """
         if not JiraInstance.instance:
             self.create_instance()
         return JiraInstance.instance
 
-    def create_instance(self):
-        if not settings.get("instance") or not settings.get("login"):
-            JiraInstance.instance = self.configure()
-        else:
-            JiraInstance.instance = JIRA(
-                settings.get("instance"),
-                basic_auth=(settings.get("login"), keyring.get_password("moic", settings.get("login")),),
-                options={"agile_rest_path": "agile", "rest_api_version": "latest", "agile_rest_api_version": "latest"},
-            )
+    def create_instance(self) -> None:
+        """
+        Setup the instance if it doesn't exist yet
 
-    def setup_home_dir(self):
+        Returns:
+            Nonte
+        """
+        if not settings.get("instance") or not settings.get("login"):
+            self.configure()
+        else:
+            try:
+                JiraInstance.instance = JIRA(
+                    settings.get("instance"),
+                    basic_auth=(settings.get("login"), keyring.get_password("moic", settings.get("login")),),
+                    options={
+                        "agile_rest_path": "agile",
+                        "rest_api_version": "latest",
+                        "agile_rest_api_version": "latest",
+                    },
+                )
+            except Exception as e:
+                console.print(f"[red]Something goes wrong {e.status_code}[/red]")
+                exit(1)
+
+    def setup_home_dir(self) -> None:
+        """
+        Setup configuration directory. It creates the root configuration directory
+        an empty .yaml conf file and the templates directory
+
+        Returns:
+            None
+        """
         if not os.path.isdir(os.path.expanduser(CONF_DIR)):
             logger.debug("Create configuration dir")
             os.makedirs(os.path.expanduser(CONF_DIR))
@@ -79,7 +117,17 @@ class JiraInstance:
                 default = {"default": {}}
                 yaml.dump(default, default_config)
 
-    def configure(self, force=False):
+    def configure(self, force: bool = False) -> None:
+        """
+        Setup the main configuration and saved it:
+        Instance, credentials and default project
+
+        Args:
+            force (bool): Force configuration to be setup even if it exists
+
+        Returns:
+            None
+        """
         if not force:
             console.print("[yellow]No configuration found[/yellow]")
         instance = click.prompt("Your Jira Instance")
@@ -94,20 +142,35 @@ class JiraInstance:
         persist = click.confirm("Would you like to persist the credentials to the local keyring?")
         if persist:
             keyring.set_password("moic", login, password)
-        auth_jira = JIRA(
-            instance,
-            basic_auth=(login, password),
-            options={"agile_rest_path": "agile", "rest_api_version": "latest", "agile_rest_api_version": "latest"},
-        )
 
-        conf = {"default": {"instance": instance, "login": login, "default_project": default_project}}
+        try:
+            JiraInstance.instance = JIRA(
+                instance,
+                basic_auth=(login, password),
+                options={"agile_rest_path": "agile", "rest_api_version": "latest", "agile_rest_api_version": "latest"},
+            )
+        except Exception as e:
+            console.print(f"[red]Something goes wrong {e.status_code}[/red]")
+            exit(1)
+
+        conf = {"default": {"instance": instance, "login": login, "project": default_project}}
         with open(os.path.expanduser(f"{CONF_DIR}/config.yaml"), "w+") as conf_file:
             yaml.dump(conf, conf_file)
 
-        console.print(f"Configuration saved: {CONF_DIR}")
-        return auth_jira
+        console.line()
+        console.print(f"[grey70]  > Configuration stored in {os.path.expanduser(CONF_DIR)}[/grey70]")
+        console.line()
 
-    def update_config(self, sub_conf):
+    def update_config(self, sub_conf: dict) -> None:
+        """
+        Update the local configuration merging in it a new dict of configuration
+
+        Args:
+            sub_conf (dict): The new configuration to merge into the config.yaml file
+
+        Returns:
+            None
+        """
         # read configuration
         with open(os.path.expanduser(f"{CONF_DIR}/config.yaml"), "r") as conf_file:
             conf = yaml.load(conf_file, Loader=yaml.FullLoader)
@@ -117,8 +180,20 @@ class JiraInstance:
         with open(os.path.expanduser(f"{CONF_DIR}/config.yaml"), "w+") as conf_file:
             yaml.dump(new_conf, conf_file)
 
-    def configure_agile(self, project, force=False):
+    def configure_agile(self, project: str, force: bool = False) -> None:
+        """
+        Configure the agile settings
+        It configured several custom fields:
+        * Story point custom field
+        * Peer custom field
 
+        Args:
+            project (str): Jira Project key which should be configured
+            force (bool): Force configuration to be setup even if it exists
+
+        Returns:
+            None
+        """
         if not settings.get("jira.custom_fields.peer") or force:
             console.print("\n[yellow]Agile configuration: custom fields for peer is not set[/yellow]")
             fields = self.session.fields()
@@ -135,8 +210,6 @@ class JiraInstance:
                 exit()
             self.update_config({"default": {"jira": {"custom_fields": {"peer": choice}}}})
 
-            console.print("[green]Agile configuration saved![/green]")
-
         if not settings.get("jira.custom_fields.story_points") or force:
             console.print("\n[yellow]Agile configuration: custom fields for story points is not set[/yellow]")
             fields = self.session.fields()
@@ -153,10 +226,8 @@ class JiraInstance:
                 exit()
             self.update_config({"default": {"jira": {"custom_fields": {"story_points": choice}}}})
 
-            console.print("[green]Agile configuration saved![/green]")
-
         if not settings.get(f"jira.projects.{project}.workflow") or force:
-            console.print("\n[yellow]Agile configuration:   workflow is not set[/yellow]")
+            console.print("\n[yellow]Agile configuration:  workflow is not set[/yellow]")
             # Get Status for the project
             statuses = get_project_story_status(
                 project,
@@ -191,12 +262,24 @@ class JiraInstance:
                 workflow_config = json.loads(workflow[0].replace("'", '"'))
                 self.update_config({"default": {"jira": {"projects": {project: {"workflow": workflow_config}}}}})
                 console.print(workflow_config)
-            console.print("[green]Agile workflow saved![/green]")
 
-        console.print(f"\n[grey70]Configuration stored in {os.path.expanduser(CONF_DIR)}[/grey70]")
+        console.print("[green]Agile workflow saved![/green]")
+        console.line()
+        console.print(f"[grey70]  > Configuration stored in {os.path.expanduser(CONF_DIR)}[/grey70]")
 
 
-def merge_dict(a, b, path=None):
+def merge_dict(a: dict, b: dict, path: str = None) -> dict:
+    """
+    Merge two dict together
+
+    Args:
+        a (dict): The main dict
+        b (dict): The secondary dict which should be merged into a
+        path (str): The path where to merde
+
+    Returns:
+        dict: The merged dict
+    """
     if path is None:
         path = []
     for key in b:
